import RDSDataService from 'aws-sdk/clients/rdsdataservice';
import _createAdapter from '@resolve-js/readmodel-base';
import crypto from 'crypto';
import _connect from './connect';
import disconnect from './disconnect';
import count from './count';
import defineTable from './define-table';
import del from './delete';
import findOne from './find-one';
import find from './find';
import insert from './insert';
import update from './update';
import buildUpsertDocument from './build-upsert-document';
import coercer from './coercer';
import convertResultRow from './convert-result-row';
import escapeId from './escape-id';
import escapeStr from './escape-str';
import searchToWhereExpression from './search-to-where-expression';
import updateToSetExpression from './update-to-set-expression';
import PassthroughError from './passthrough-error';
import inlineLedgerExecuteTransaction from './inline-ledger-execute-transaction';
import inlineLedgerExecuteStatement from './inline-ledger-execute-statement';
import inlineLedgerForceStop from './inline-ledger-force-stop';
import generateGuid from './generate-guid';
import maybeInit from './maybe-init';
import dropReadModel from './drop-read-model';
import subscribe from './subscribe';
import resubscribe from './resubscribe';
import unsubscribe from './unsubscribe';
import reset from './reset';
import pause from './pause';
import resume from './resume';
import status from './status';
import build from './build';
import _createResource from './resource/create';
import _destroyResource from './resource/destroy';
const store = {
  defineTable,
  find,
  findOne,
  count,
  insert,
  update,
  delete: del
};
const internalMethods = {
  buildUpsertDocument,
  convertResultRow,
  searchToWhereExpression,
  updateToSetExpression,
  coercer,
  generateGuid,
  PassthroughError,
  inlineLedgerExecuteTransaction,
  inlineLedgerExecuteStatement,
  inlineLedgerForceStop,
  dropReadModel,
  maybeInit,
  escapeId,
  escapeStr
};
const externalMethods = {
  subscribe,
  resubscribe,
  unsubscribe,
  resume,
  pause,
  reset,
  status,
  build
};

const connect = _connect.bind(null, {
  RDSDataService,
  crypto,
  ...internalMethods,
  ...externalMethods,
  ...store
});

const implementation = { ...store,
  ...externalMethods,
  connect,
  disconnect
};

const createAdapter = _createAdapter.bind(null, implementation);

export default createAdapter;
const pool = {
  connect,
  disconnect,
  escapeId,
  escapeStr
};

const createResource = _createResource.bind(null, pool);

const destroyResource = _destroyResource.bind(null, pool);

Object.assign(pool, {
  createResource,
  destroyResource
});
export { createResource as create, destroyResource as destroy };
//# sourceMappingURL=index.js.map