"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.destroy = exports.create = exports.default = void 0;

var _rdsdataservice = _interopRequireDefault(require("aws-sdk/clients/rdsdataservice"));

var _readmodelBase = _interopRequireDefault(require("@resolve-js/readmodel-base"));

var _crypto = _interopRequireDefault(require("crypto"));

var _connect2 = _interopRequireDefault(require("./connect"));

var _disconnect = _interopRequireDefault(require("./disconnect"));

var _count = _interopRequireDefault(require("./count"));

var _defineTable = _interopRequireDefault(require("./define-table"));

var _delete = _interopRequireDefault(require("./delete"));

var _findOne = _interopRequireDefault(require("./find-one"));

var _find = _interopRequireDefault(require("./find"));

var _insert = _interopRequireDefault(require("./insert"));

var _update = _interopRequireDefault(require("./update"));

var _buildUpsertDocument = _interopRequireDefault(require("./build-upsert-document"));

var _coercer = _interopRequireDefault(require("./coercer"));

var _convertResultRow = _interopRequireDefault(require("./convert-result-row"));

var _escapeId = _interopRequireDefault(require("./escape-id"));

var _escapeStr = _interopRequireDefault(require("./escape-str"));

var _searchToWhereExpression = _interopRequireDefault(require("./search-to-where-expression"));

var _updateToSetExpression = _interopRequireDefault(require("./update-to-set-expression"));

var _passthroughError = _interopRequireDefault(require("./passthrough-error"));

var _inlineLedgerExecuteTransaction = _interopRequireDefault(require("./inline-ledger-execute-transaction"));

var _inlineLedgerExecuteStatement = _interopRequireDefault(require("./inline-ledger-execute-statement"));

var _inlineLedgerForceStop = _interopRequireDefault(require("./inline-ledger-force-stop"));

var _generateGuid = _interopRequireDefault(require("./generate-guid"));

var _maybeInit = _interopRequireDefault(require("./maybe-init"));

var _dropReadModel = _interopRequireDefault(require("./drop-read-model"));

var _subscribe = _interopRequireDefault(require("./subscribe"));

var _resubscribe = _interopRequireDefault(require("./resubscribe"));

var _unsubscribe = _interopRequireDefault(require("./unsubscribe"));

var _reset = _interopRequireDefault(require("./reset"));

var _pause = _interopRequireDefault(require("./pause"));

var _resume = _interopRequireDefault(require("./resume"));

var _status = _interopRequireDefault(require("./status"));

var _build = _interopRequireDefault(require("./build"));

var _create = _interopRequireDefault(require("./resource/create"));

var _destroy = _interopRequireDefault(require("./resource/destroy"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const store = {
  defineTable: _defineTable.default,
  find: _find.default,
  findOne: _findOne.default,
  count: _count.default,
  insert: _insert.default,
  update: _update.default,
  delete: _delete.default
};
const internalMethods = {
  buildUpsertDocument: _buildUpsertDocument.default,
  convertResultRow: _convertResultRow.default,
  searchToWhereExpression: _searchToWhereExpression.default,
  updateToSetExpression: _updateToSetExpression.default,
  coercer: _coercer.default,
  generateGuid: _generateGuid.default,
  PassthroughError: _passthroughError.default,
  inlineLedgerExecuteTransaction: _inlineLedgerExecuteTransaction.default,
  inlineLedgerExecuteStatement: _inlineLedgerExecuteStatement.default,
  inlineLedgerForceStop: _inlineLedgerForceStop.default,
  dropReadModel: _dropReadModel.default,
  maybeInit: _maybeInit.default,
  escapeId: _escapeId.default,
  escapeStr: _escapeStr.default
};
const externalMethods = {
  subscribe: _subscribe.default,
  resubscribe: _resubscribe.default,
  unsubscribe: _unsubscribe.default,
  resume: _resume.default,
  pause: _pause.default,
  reset: _reset.default,
  status: _status.default,
  build: _build.default
};

const connect = _connect2.default.bind(null, {
  RDSDataService: _rdsdataservice.default,
  crypto: _crypto.default,
  ...internalMethods,
  ...externalMethods,
  ...store
});

const implementation = { ...store,
  ...externalMethods,
  connect,
  disconnect: _disconnect.default
};

const createAdapter = _readmodelBase.default.bind(null, implementation);

var _default = createAdapter;
exports.default = _default;
const pool = {
  connect,
  disconnect: _disconnect.default,
  escapeId: _escapeId.default,
  escapeStr: _escapeStr.default
};

const createResource = _create.default.bind(null, pool);

exports.create = createResource;

const destroyResource = _destroy.default.bind(null, pool);

exports.destroy = destroyResource;
Object.assign(pool, {
  createResource,
  destroyResource
});
//# sourceMappingURL=index.js.map