"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

const inlineLedgerExecuteTransaction = async (...args) => {
  const [pool, method, inputTransactionId] = args;
  const {
    PassthroughError,
    rdsDataService,
    dbClusterOrInstanceArn,
    awsSecretStoreArn
  } = pool;

  switch (method) {
    case 'begin':
      {
        for (;;) {
          try {
            const {
              transactionId
            } = await rdsDataService.beginTransaction({
              resourceArn: dbClusterOrInstanceArn,
              secretArn: awsSecretStoreArn,
              database: 'postgres'
            }).promise();
            return transactionId;
          } catch (error) {
            PassthroughError.maybeThrowPassthroughError(error, null, false);
          }
        }
      }

    case 'commit':
      {
        for (;;) {
          try {
            await rdsDataService.commitTransaction({
              resourceArn: dbClusterOrInstanceArn,
              secretArn: awsSecretStoreArn,
              transactionId: inputTransactionId
            }).promise();
            return null;
          } catch (error) {
            PassthroughError.maybeThrowPassthroughError(error, null, false);
          }
        }
      }

    case 'rollback':
      {
        for (;;) {
          try {
            await rdsDataService.rollbackTransaction({
              resourceArn: dbClusterOrInstanceArn,
              secretArn: awsSecretStoreArn,
              transactionId: inputTransactionId
            }).promise();
            return null;
          } catch (error) {
            PassthroughError.maybeThrowPassthroughError(error, null, false);
          }
        }
      }

    default:
      {
        throw new Error(`Invalid inline ledger transaction operation "${method}"`);
      }
  }
};

var _default = inlineLedgerExecuteTransaction;
exports.default = _default;
//# sourceMappingURL=inline-ledger-execute-transaction.js.map