/// <reference types="node" />
import type { ObjectFixedIntersectionToObject, CommonAdapterPool, CommonAdapterOptions, AdapterOperations, AdapterConnection, AdapterImplementation, StoreApi, PerformanceTracerLike, SplitNestedPathMethod, MatchTypeConditional, JsonMap, SearchCondition, UpdateCondition, ObjectFixedKeys, OmitObject, JsonPrimitive } from '@resolve-js/readmodel-base';
import type RDSDataService from 'aws-sdk/clients/rdsdataservice';
import type crypto from 'crypto';
export * from '@resolve-js/readmodel-base';
export declare type LibDependencies = {
    RDSDataService: typeof RDSDataService;
    crypto: typeof crypto;
};
export declare type InlineLedgerExecuteStatementMethod = ((pool: AdapterPool, querySQL: string, transactionId?: string | null | symbol, passthroughRuntimeErrors?: boolean) => Promise<Array<object>>) & {
    SHARED_TRANSACTION_ID: symbol;
};
export declare type InlineLedgerExecuteTransactionMethodNames = 'begin' | 'commit' | 'rollback';
export declare type InlineLedgerExecuteTransactionMethodParameters<MethodName extends InlineLedgerExecuteTransactionMethodNames> = [
    pool: AdapterPool,
    method: MethodName,
    ...args: MatchTypeConditional<MethodName, [
        [
            'begin',
            []
        ],
        [
            'commit',
            [transactionId: string]
        ],
        [
            'rollback',
            [transactionId: string]
        ]
    ]>
];
export declare type InlineLedgerExecuteTransactionMethodReturnType<MethodName extends InlineLedgerExecuteTransactionMethodNames> = MatchTypeConditional<MethodName, [
    [
        'begin',
        string
    ],
    [
        'commit',
        null | undefined
    ],
    [
        'rollback',
        null | undefined
    ]
]>;
export declare type InlineLedgerExecuteTransactionMethod = <MethodName extends InlineLedgerExecuteTransactionMethodNames>(...args: InlineLedgerExecuteTransactionMethodParameters<MethodName>) => Promise<InlineLedgerExecuteTransactionMethodReturnType<MethodName>>;
export declare type FullJitterMethod = (retries: number) => Promise<void>;
export declare type MakeNestedPathMethod = (nestedPath: Array<string>) => string;
export declare type EscapeableMethod = (str: string) => string;
export declare type InlineLedgerForceStopMethod = (pool: AdapterPool, readModelName: string) => Promise<void>;
export declare type BuildUpsertDocumentMethod = (searchExpression: Parameters<StoreApi<CommonAdapterPool>['update']>[3], updateExpression: Parameters<StoreApi<CommonAdapterPool>['update']>[4], splitNestedPath: SplitNestedPathMethod) => JsonMap;
export declare type RowLike = JsonMap;
export declare type MarshalledRowLike = RowLike & {
    marshalled: 'marshalled';
};
export declare type ConvertResultRowMethod = (inputRow: MarshalledRowLike, fieldList: Parameters<StoreApi<CommonAdapterPool>['find']>[4] | null) => RowLike;
export declare type SearchToWhereExpressionMethod = (expression: SearchCondition, escapeId: EscapeableMethod, escapeStr: EscapeableMethod, makeNestedPath: MakeNestedPathMethod, splitNestedPath: SplitNestedPathMethod) => string;
export declare type UpdateToSetExpressionMethod = (expression: UpdateCondition, escapeId: EscapeableMethod, escapeStr: EscapeableMethod, makeNestedPath: MakeNestedPathMethod, splitNestedPath: SplitNestedPathMethod) => string;
export interface PassthroughErrorInstance extends Error {
    name: string;
    lastTransactionId: string | null | undefined;
    isRetryable: boolean;
    isEmptyTransaction: boolean;
}
export declare type PassthroughErrorLike = Error & {
    code: string | number;
    stack: string;
};
export declare type PassthroughErrorFactory = {
    new (lastTransactionId: string | null | undefined, isRetryable: boolean, isEmptyTransaction: boolean): PassthroughErrorInstance;
} & {
    isShortCircuitPassthroughError: (error: PassthroughErrorLike) => boolean;
    isRetryablePassthroughError: (error: PassthroughErrorLike) => boolean;
    isRegularFatalPassthroughError: (error: PassthroughErrorLike) => boolean;
    isRuntimeFatalPassthroughError: (error: PassthroughErrorLike) => boolean;
    isPassthroughError: (error: PassthroughErrorLike, includeRuntimeErrors: boolean) => boolean;
    isEmptyTransactionError: (error: PassthroughErrorLike) => boolean;
    maybeThrowPassthroughError: (error: PassthroughErrorLike, transactionId: string | null, includeRuntimeErrors: boolean) => void;
};
export declare type GenerateGuidMethod = (...args: any) => string;
export declare type DropReadModelMethod = (pool: AdapterPool, readModelName: string) => Promise<void>;
export declare type AdapterOptions = CommonAdapterOptions & {
    dbClusterOrInstanceArn: RDSDataService.Arn;
    awsSecretStoreArn: RDSDataService.Arn;
    databaseName: RDSDataService.DbName;
    tablePrefix?: string;
} & RDSDataService.ClientConfiguration;
export declare type MaybeInitMethod = (pool: AdapterPool) => Promise<void>;
export declare type InternalMethods = {
    inlineLedgerExecuteTransaction: InlineLedgerExecuteTransactionMethod;
    inlineLedgerExecuteStatement: InlineLedgerExecuteStatementMethod;
    inlineLedgerForceStop: InlineLedgerForceStopMethod;
    buildUpsertDocument: BuildUpsertDocumentMethod;
    convertResultRow: ConvertResultRowMethod;
    searchToWhereExpression: SearchToWhereExpressionMethod;
    updateToSetExpression: UpdateToSetExpressionMethod;
    PassthroughError: PassthroughErrorFactory;
    generateGuid: GenerateGuidMethod;
    dropReadModel: DropReadModelMethod;
    escapeId: EscapeableMethod;
    escapeStr: EscapeableMethod;
    maybeInit: MaybeInitMethod;
    coercer: CoercerMethod;
};
export declare type ArrayOrSingleOrNull<T> = Array<T> | T | null;
export declare type UpdateFieldDescriptor = {
    [K in ObjectFixedKeys<ObjectFixedIntersectionToObject<UpdateCondition>>]: ObjectFixedIntersectionToObject<UpdateCondition>[K][string] | null;
} & {
    key: string;
    nestedKey: string[];
    baseName: string;
    selectedOperation: ObjectFixedKeys<UpdateCondition> | null;
    children: Map<string, UpdateFieldDescriptor>;
    operations?: ArrayOrSingleOrNull<{
        operationName: ObjectFixedKeys<UpdateCondition> | null;
        fieldValue: UpdateFieldDescriptor[ObjectFixedKeys<UpdateCondition>];
        nestedPath?: string[];
    }>;
};
export declare type CoercerMethod = (value: {
    intValue?: number;
    stringValue?: string;
    bigIntValue?: number;
    longValue?: number;
    booleanValue?: boolean;
    isNull?: boolean;
}) => JsonPrimitive;
export declare type AdapterPool = CommonAdapterPool & {
    hash512: (str: string) => string;
    performanceTracer: PerformanceTracerLike;
    makeNestedPath: MakeNestedPathMethod;
    rdsDataService: InstanceType<LibDependencies['RDSDataService']>;
    dbClusterOrInstanceArn: RDSDataService.Arn;
    awsSecretStoreArn: RDSDataService.Arn;
    schemaName: RDSDataService.DbName;
    tablePrefix: string;
    sharedTransactionId?: string | null | undefined;
    activePassthrough: boolean;
} & {
    [K in keyof AdapterOperations<CommonAdapterPool>]: AdapterOperations<AdapterPool>[K];
} & {
    [K in keyof StoreApi<CommonAdapterPool>]: StoreApi<AdapterPool>[K];
} & InternalMethods;
export declare type CurrentAdapterConnection = AdapterConnection<AdapterPool, OmitObject<AdapterOptions, CommonAdapterPool>>;
export declare type ExternalMethods = {
    [K in keyof AdapterOperations<CommonAdapterPool>]: AdapterPool[K];
};
export declare type CurrentStoreApi = {
    [K in keyof StoreApi<CommonAdapterPool>]: AdapterPool[K];
};
export declare type ConnectionDependencies = LibDependencies & InternalMethods & ExternalMethods & CurrentStoreApi;
export declare type CurrentConnectMethod = (imports: ConnectionDependencies, ...args: Parameters<CurrentAdapterConnection['connect']>) => ReturnType<CurrentAdapterConnection['connect']>;
export declare type CurrentDisconnectMethod = CurrentAdapterConnection['disconnect'];
export declare type CurrentAdapterImplementation = AdapterImplementation<AdapterPool, AdapterOptions>;
export declare type AdminOptions = {
    awsSecretStoreAdminArn: AdapterOptions['awsSecretStoreArn'];
    dbClusterOrInstanceArn: AdapterOptions['dbClusterOrInstanceArn'];
    databaseName: AdapterOptions['databaseName'];
    region: AdapterOptions['region'];
    userLogin: string;
};
export declare type BoundResourceMethod = (options: AdminOptions) => Promise<void>;
export declare type UnboundResourceMethod = (pool: AdminPool, options: AdminOptions) => Promise<void>;
export declare type AdminPool = {
    connect: CurrentAdapterImplementation['connect'];
    disconnect: CurrentAdapterImplementation['disconnect'];
    escapeStr: EscapeableMethod;
    escapeId: EscapeableMethod;
    createResource: BoundResourceMethod;
    destroyResource: BoundResourceMethod;
};
